/**
 * Information to cache about a file
 */
export interface FileInfo {
    absolutePath: string;
    exists: boolean;
}
/**
 * Cached information about a file
 */
export interface CachedFileInfo extends FileInfo {
    expires: number;
}
/**
 * A cache of whether file information, to save redundant disk I/O.
 */
export declare class FileCache {
    #private;
    constructor(timeout: number);
    /**
     * Adds a file to the cache
     */
    add(file: FileInfo): void;
    /**
     * Adds a file to the cache while its info is being read from disk
     */
    addPending(absolutePath: string, promise: Promise<FileInfo>): void;
    /**
     * Removes a file from the cache
     */
    remove(absolutePath: string): void;
    /**
     * Removes a file from the cache
     */
    get(absolutePath: string): Promise<CachedFileInfo>;
}
